@@ -20,7 +20,7 @@ from sphinx.util.docutils import SphinxDirective
 
 from sphinx.ext.autodoc import (
     ClassDocumenter, ModuleDocumenter, ALL, PycodeError,
-    ModuleAnalyzer, bool_option, AttributeDocumenter, DataDocumenter, Options,
+    ModuleAnalyzer, AttributeDocumenter, DataDocumenter, Options,
     prepare_docstring)
 import sphinx.ext.autodoc as ad
 
@@ -40,7 +40,12 @@ except ImportError:
 
 sphinx_version = list(map(float, re.findall(r'\d+', sphinx.__version__)[:3]))
 
-from sphinx.util import force_decode
+try:
+    from sphinx.util import force_decode
+except ImportError:
+    # force_decode has been removed with sphinx 4.0
+    def force_decode(string: str, encoding: str) -> str:
+        return string
 
 
 try:
@@ -51,7 +56,7 @@ except ImportError:
     except ImportError:
         from ordereddict import OrderedDict
 
-__version__ = '0.2.2'
+__version__ = '0.2.4'
 
 __author__ = "Philipp S. Sommer"
 
@@ -85,6 +90,19 @@ def list_option(option):
     return [s.strip() for s in option.split(";;")]
 
 
+def bool_option(*args):
+    return "True"
+
+
+def _get_arg(param, pos, default, *args, **kwargs):
+    if param in kwargs:
+        return kwargs[param]
+    elif len(args) > pos:
+        return args[pos]
+    else:
+        return default
+
+
 class AutosummaryDocumenter(object):
     """Abstract class for for extending Documenter methods
 
@@ -155,7 +173,7 @@ class AutosummaryDocumenter(object):
             self.env.temp_data['autodoc:class'] = self.objpath[0]
 
         if not self.options.autosummary_force_inline:
-            docstring = self.get_doc()
+            docstring = self.get_doc() or []
             autodocsumm_directive = '.. auto%ssumm::' % self.objtype
             for s in chain.from_iterable(docstring):
                 if autodocsumm_directive in s:
@@ -230,7 +248,10 @@ class AutosummaryDocumenter(object):
 
     def add_autosummary(self):
         """Add the autosammary table of this documenter."""
-        if self.options.autosummary:
+        if (
+            self.options.get("autosummary")
+            and not self.options.get("no-autosummary")
+        ):
 
             grouped_documenters = self.get_grouped_documenters()
 
@@ -243,6 +264,8 @@ class AutosummaryDocumenter(object):
                 self.add_line('', sourcename)
 
                 self.add_line('.. autosummary::', sourcename)
+                if self.options.autosummary_nosignatures:
+                    self.add_line('    :nosignatures:', sourcename)
                 self.add_line('', sourcename)
                 indent = '    '
 
@@ -273,6 +296,7 @@ class AutoSummModuleDocumenter(ModuleDocumenter, AutosummaryDocumenter):
     option_spec['autosummary-sections'] = list_option
     option_spec['autosummary-no-titles'] = bool_option
     option_spec['autosummary-force-inline'] = bool_option
+    option_spec['autosummary-nosignatures'] = bool_option
 
     #: Add options for members for the autosummary
     for _option in member_options.intersection(option_spec):
@@ -296,8 +320,8 @@ class AutoSummModuleDocumenter(ModuleDocumenter, AutosummaryDocumenter):
 
         self.add_autosummary()
 
-        if self.options.autosummary_no_nesting:
-            self.options.autosummary = False
+        if self.options.get("autosummary-no-nesting"):
+            self.options["no-autosummary"] = "True"
 
 
 class AutoSummClassDocumenter(ClassDocumenter, AutosummaryDocumenter):
@@ -322,6 +346,7 @@ class AutoSummClassDocumenter(ClassDocumenter, AutosummaryDocumenter):
     option_spec['autosummary-sections'] = list_option
     option_spec['autosummary-no-titles'] = bool_option
     option_spec['autosummary-force-inline'] = bool_option
+    option_spec['autosummary-nosignatures'] = bool_option
 
     #: Add options for members for the autosummary
     for _option in member_options.intersection(option_spec):
@@ -358,13 +383,14 @@ class CallableDataDocumenter(DataDocumenter):
             return None
         return process_signature(callmeth)
 
-    def get_doc(self, encoding=None, ignore=1):
+    def get_doc(self, *args, **kwargs):
         """Reimplemented  to include data from the call method"""
         content = self.env.config.autodata_content
         if content not in ('both', 'call') or not self.get_attr(
                 self.get_attr(self.object, '__call__', None), '__doc__'):
             return super(CallableDataDocumenter, self).get_doc(
-                encoding=encoding, ignore=ignore)
+                *args, **kwargs
+            )
 
         # for classes, what the "docstring" is can be controlled via a
         # config value; the default is both docstrings
@@ -402,13 +428,14 @@ class CallableAttributeDocumenter(AttributeDocumenter):
             return None
         return process_signature(callmeth)
 
-    def get_doc(self, encoding=None, ignore=1):
+    def get_doc(self, *args, **kwargs):
         """Reimplemented  to include data from the call method"""
         content = self.env.config.autodata_content
         if content not in ('both', 'call') or not self.get_attr(
                 self.get_attr(self.object, '__call__', None), '__doc__'):
             return super(CallableAttributeDocumenter, self).get_doc(
-                encoding=encoding, ignore=ignore)
+                *args, **kwargs
+            )
 
         # for classes, what the "docstring" is can be controlled via a
         # config value; the default is both docstrings
@@ -424,10 +451,17 @@ class CallableAttributeDocumenter(AttributeDocumenter):
             docstrings.append(calldocstring + '\n')
 
         doc = []
-        for docstring in docstrings:
-            if not isinstance(docstring, str):
-                docstring = force_decode(docstring, encoding)
-            doc.append(prepare_docstring(docstring, ignore))
+        if sphinx_version < [4, 0]:
+            encoding = _get_arg("encoding", 0, None, *args, **kwargs)
+            ignore = _get_arg("ignore", 1, 1, *args, **kwargs)
+            for docstring in docstrings:
+                if not isinstance(docstring, str):
+                    docstring = force_decode(docstring, encoding)
+                doc.append(prepare_docstring(docstring, ignore))
+        else:
+            ignore = _get_arg("ignore", 0, 1, *args, **kwargs)
+            for docstring in docstrings:
+                doc.append(prepare_docstring(docstring, ignore))
 
         return doc
 
@@ -524,10 +558,10 @@ class AutoDocSummDirective(SphinxDirective):
         objtype = self.name[4:-4]  # strip prefix (auto-) and suffix (-summ).
         doccls = self.env.app.registry.documenters[objtype]
 
-        self.options['autosummary-force-inline'] = True
-        self.options['autosummary'] = True
+        self.options['autosummary-force-inline'] = "True"
+        self.options['autosummary'] = "True"
         if 'no-members' not in self.options:
-            self.options['members'] = True
+            self.options['members'] = ""
 
         # process the options with the selected documenter's option_spec
         try:
